@@ -27,7 +27,7 @@ interpreters and their regular expressions. A sample one is:
 
 =cut
 
-our $VERSION = '0.0124';
+our $VERSION = '0.0125';
 
 =head2 $self->private_backend_plugins()
 
@@ -86,10 +86,6 @@ You can also look for information at:
 
 =over 4
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Test::Run::CmdLine::Plugin::AlternateInterpreters>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Test::Run::Plugin::AlternateInterpreters>
@@ -120,7 +116,7 @@ L<Test::Run::CmdLine>, L<TAP::Parser>
 
 Copyright 2007 Shlomi Fish, all rights reserved.
 
-This program is released under the following license: MIT X11.
+This program is released under the following license: MIT Expat.
 
 =cut
 
